<?php

/*  
    Copyright 2011  Maxime Dizerens  (email : mdizerens@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
Plugin Name: PHPLeague for WordPress
Plugin URI: http://www.mika-web.com/phpleague-for-wordpress/
Description: PHPLeague for WordPress is the best plugin to manage properly your sports leagues. This plugin has also a Premium version with all the features you might need.
Version: 1.2
Author: Maxime Dizerens
Author URI: http://www.mika-web.com/
*/

// Constants
define('WP_PHPLEAGUE_VERSION', '1.2');
define('WP_PHPLEAGUE_DB_VERSION', '1.1');
define('WP_PHPLEAGUE_PATH', plugin_dir_path( __FILE__ ));

// PHPLeague Translation
load_plugin_textdomain('phpleague', FALSE, WP_PHPLEAGUE_PATH.'i18n');

// Core files
require_once WP_PHPLEAGUE_PATH.'libs/mwd-plugin-tools.php';
require_once WP_PHPLEAGUE_PATH.'libs/phpleague-database.php';

// Specific actions
register_activation_hook(__FILE__, array('MWD_Plugin_Igniter', 'activate'));
register_deactivation_hook(__FILE__, array('MWD_Plugin_Igniter', 'deactivate'));
register_uninstall_hook(__FILE__, array('MWD_Plugin_Igniter', 'uninstall'));

if ( ! class_exists('PHPLeague_Admin') && is_admin() && ( ! defined('DOING_AJAX') || ! DOING_AJAX)) {
	
	class PHPLeague_Admin extends MWD_Plugin_Tools {

		public $longname  = 'PHPLeague for WordPress';
		public $shortname = 'PHPLeague for WP';
		public $access	  = 'administrator';
		public $pages 	  = array('phpleague_about', 'phpleague_overview', 'phpleague_club', 'phpleague_setting');

		/**
	     * Constructor
	     */
		public function __construct()
		{
			parent::__construct();
			
			add_action('init', array(&$this, 'add_editor_button'));
			add_action('admin_init', array(&$this, 'plugin_admin_init'));
			add_action('admin_init', array(&$this, 'plugin_check_upgrade'));
			add_action('admin_menu', array(&$this, 'admin_menu'));
            add_action('admin_print_styles', array(&$this, 'print_admin_styles'));
			add_action('admin_print_scripts', array(&$this, 'print_admin_scripts'));
			
			$this->define_tables();
		}
		
        /**
	     * Add the admin styles
	     */
		public function print_admin_styles()
		{
			if (isset($_GET['page'])) {
				if ( ! in_array(trim($_GET['page']), $this->pages))
				 	return;
			}
			
			$handle  = 'phpleague-admin';

			wp_register_style($handle, plugins_url('phpleague/assets/css/phpleague-admin.css'));
		    wp_enqueue_style($handle);
		}
		
		/**
	     * Add the admin scripts
	     */
		public function print_admin_scripts()
		{
			if (isset($_GET['page'])) {
				if ( ! in_array(trim($_GET['page']), $this->pages))
				 	return;
			}
			
			wp_register_script('phpleague', plugins_url('phpleague/assets/js/admin.js'));
			wp_enqueue_script('phpleague');
		}
		
		/**
	     * Generate the admin menu
		 *
		 * @param  none
		 * @return void
	     */
		public function admin_menu()
		{           
            require_once WP_PHPLEAGUE_PATH.'libs/phpleague-admin.php';

			$instance = new PHPLeague_Admin_Controller();
			$parent   = 'phpleague_overview';
			
			if (function_exists('add_menu_page')) {
				add_menu_page(
					__('Dashboard (PHPLeague)'),
					__('PHPLeague'),
					$this->access,
					$parent,
					array($instance, 'admin_page'),
					plugins_url('phpleague/assets/img/league.png')
				);
			}
			
			if (function_exists('add_submenu_page')) {
				add_submenu_page(
					$parent,
					__('Clubs (PHPLeague)'),
					__('Clubs'),
					$this->access,
					'phpleague_club',
					array($instance, 'admin_page')
				);
				
				add_submenu_page(
					$parent,
					__('Settings (PHPLeague)'),
					__('Settings'),
					$this->access,
					'phpleague_setting',
					array($instance, 'admin_page')
				);
				
				add_submenu_page(
					$parent,
					__('About (PHPLeague)'),
					__('About'),
					$this->access,
					'phpleague_about',
					array($instance, 'admin_page')
				);
			}
		}
		
		/**
		 * Add TinyMCE Button
		 *
		 * @param  none
		 * @return void
		 */
		public function add_editor_button()
		{
			// Don't bother doing this stuff if the current user lacks permissions
			if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages')) return;

			// Check for PHPLeague capability
			if ( ! current_user_can('phpleague')) return;

			// Add only in Rich Editor mode
			if (get_user_option('rich_editing') == 'true') {
				add_filter('mce_external_plugins', array(&$this, 'add_editor_plugin'));
				add_filter('mce_buttons', array(&$this, 'register_editor_button'));
			}
		}
		
		/**
		 * Add TinyMCE plugin
		 *
		 * @param  array
		 * @return void
		 */
		public function add_editor_plugin($plugin_array)
		{
			$plugin_array['PHPLeague'] = plugins_url('phpleague/assets/js/tinymce/editor_plugin.js');
			return $plugin_array;
		}
		
		/**
		 * Register TinyMCE button
		 *
		 * @param  array
		 * @return void
		 */
		public function register_editor_button($buttons)
		{
			array_push($buttons, 'separator', 'PHPLeague');
			return $buttons;
		}
	}
	
	$phpleague_admin = new PHPLeague_Admin();
}

if ( ! class_exists('PHPLeague_Front') && ! is_admin() && ( ! defined('DOING_AJAX') || ! DOING_AJAX)) {
	
	class PHPLeague_Front extends MWD_Plugin_Tools {

		public $longname  = 'PHPLeague for WordPress';
		public $shortname = 'PHPLeague for WP';
		public $access	  = '';

		public function __construct()
		{
			parent::__construct();
			
			add_action('wp_print_styles', array(&$this, 'print_front_styles'));
			add_shortcode('phpleague', array(&$this, 'display_phpleague'));
			
			$this->define_tables();
		}
		
		/**
	     * Add the front css
	     */
		public function print_front_styles()
		{
			$handle  = 'phpleague-front';
            $css_src = plugins_url('phpleague/assets/css/phpleague-front.css');

			wp_register_style($handle, $css_src);
		    wp_enqueue_style($handle);
		}
		
		// We got all the public functions in here
		public function display_phpleague($atts)
		{
			extract(shortcode_atts(array('id' => 1, 'type' => 'table', 'style' => 'general', 'id_team' => ''), $atts));
			$id = intval($id);
			
			if ($type == 'table') {
				if ($style == 'home') {
					return $this->get_league_table($id, 'home');
				}
				elseif ($style == 'away') {
					return $this->get_league_table($id, 'away');
				}
				else {
					return $this->get_league_table($id);
				}
			} elseif ($type == 'fixtures') {
				if ( ! empty($id_team)) {
					return $this->get_league_fixtures($id, $id_team);
				} else {
					return $this->get_league_fixtures($id);
				}
				
			} else {
				return $this->get_league_table($id);
			}
		}
		
		// display the league table in the front area
		public function get_league_table($id, $type = 'general')
		{
			global $wpdb;
			
			$db = new PHPLeague_Database();
			
			// $id not in the database
			if ($db->is_league_exists($id) === FALSE) {
				return;
			}
			
			$setting    = $db->get_league_settings($id);
			$nb_teams  	= intval($setting->nb_teams);
			$promotion 	= intval($setting->promotion);
			$qualifying	= intval($setting->qualifying) + $promotion;
			$favorite   = intval($setting->id_favorite);
			$relegation = $nb_teams - intval($setting->relegation);
			
			$output =
			'<table id="phpleague">
				<thead>
					<tr>
						<th class="centered">'.__('Pos').'</th>
						<th>'.__('Team').'</th>
						<th class="centered">'.__('Pts').'</th>
						<th class="centered">'.__('P').'</th>
						<th class="centered">'.__('W').'</th>
						<th class="centered">'.__('D').'</th>
						<th class="centered">'.__('L').'</th>
						<th class="centered">'.__('F').'</th>
						<th class="centered">'.__('A').'</th>
						<th class="centered">'.__('+/-').'</th>
						<th class="centered"></th>
					</tr>
				</thead>
				<tbody>';

			$place = 1;

			foreach ($db->get_league_table_data($type, $id, $nb_teams) as $row) {
				if ($place <= $nb_teams) {				
					if ($favorite == $row->id_team) {
						$output .= '<tr class="id-favorite">';
					} else {
						$output .= '<tr>';
					}

					if ($place <= $promotion) {
						$span = '<span class="promotion"></span>';
					} elseif ($place <= $qualifying) {
						$span = '<span class="qualifying"></span>';
					} elseif ($place > $relegation) {
						$span = '<span class="relegation"></span>';
					} else {
						$span = '<span></span>';
					}

					$output .= '<td class="centered">'.$place.'</td>';
					$output .= '<td>'.esc_html($row->club_name).'</td>';
					$output .= '<td class="centered">'.intval($row->points).'</td>';
					$output .= '<td class="centered">'.intval($row->played).'</td>';
					$output .= '<td class="centered">'.intval($row->victory).'</td>';
					$output .= '<td class="centered">'.intval($row->draw).'</td>';
					$output .= '<td class="centered">'.intval($row->defeat).'</td>';
					$output .= '<td class="centered">'.intval($row->goal_for).'</td>';
					$output .= '<td class="centered">'.intval($row->goal_against).'</td>';
					$output .= '<td class="centered">'.intval($row->diff).'</td>';
					$output .= '<td class="centered">'.$span.'</td></tr>';
					
					$place++;
				}
			}

			$output .= '</tbody></table>';
			return $output;
		}
		
		// display the league fixtures in the front area
		public function get_league_fixtures($id_league, $id_team = NULL)
		{
			global $wpdb;
			
			$db = new PHPLeague_Database();
			
			// $id not in the database
			if ($db->is_league_exists($id_league) === FALSE) {
				return;
			}
			
			// if TRUE team does not exist in the league
			$team_exist = $db->is_team_already_in_league($id_league, $id_team);
			
			$setting  = $db->get_league_settings($id_league);
			$id_team  = ((isset($id_team) && $team_exist === FALSE) ? intval($id_team) : intval($setting->id_favorite));
			
			$output  = '<table id="phpleague"><tbody>';
			$output .=
				'<tr>
					<th>'.__('Date').'</th>
					<th class="centered">'.__('Fixture').'</th>
					<th>'.__('Match').'</th>
					<th class="centered">'.__('Score').'</th>
				</tr>';
			
			foreach ($db->get_league_fixtures_by_team($id_team, $id_league) as $row) {
				$output .= '<tr>';
				$output .= '<td>'.strftime("%a %e, %H:%S", strtotime($row->played)).'</td>';
				$output .= '<td class="centered">'.intval($row->number).'</td>';
				$output .= '<td>'.esc_html($row->home_name).' - '.esc_html($row->away_name).'</td>';
				
				if (date('Y-m-d') >= $row->played) {
					$output .= '<td class="centered">'.intval($row->goal_home).' - '.intval($row->goal_away).'</td>';
				} else {
					$output .= '<td class="centered"> - </td>';
				}	
					
				$output .= '</tr>';
			}

			$output .= '</tbody></table>';
			return $output;
		}
	}
	
	$phpleague_front = new PHPLeague_Front();
}